Find equilibrium points for a vector field
find_eqs(vf, starts, jacobian_params = list(), ...)A list of equilibrium points and their details. Use print.vectorfield_eqs() to inspect it.
A vectorfield object estimated by fit_2d_vf().
A vector indicating the starting value for solving the equilibrium point, or a list of vectors providing multiple starting values together.
Parameters passed to numDeriv::jacobian().
Parameters passed to rootSolve::multiroot().