A toolbox for estimating vector fields from intensive longitudinal data, and construct potential landscapes thereafter. The vector fields can be estimated with two nonparametric methods: the Multivariate Vector Field Kernel Estimator (MVKE) by Bandi & Moloche (2018) tools:::Rd_expr_doi("10.1017/S0266466617000305") and the Sparse Vector Field Consensus (SparseVFC) algorithm by Ma et al. (2013) tools:::Rd_expr_doi("10.1016/j.patcog.2013.05.017"). The potential landscapes can be constructed with a simulation-based approach with the 'simlandr' package (Cui et al., 2021) tools:::Rd_expr_doi("10.31234/osf.io/pzva3"), or the Bhattacharya et al. (2011) method for path integration tools:::Rd_expr_doi("10.1186/1752-0509-5-85").
Maintainer: Jingmeng Cui jingmeng.cui@outlook.com (ORCID)
Useful links: