View source: R/vectorfield_simulation.R
| simlandr_options | R Documentation |
To control the behavior of simlandr::make_3d_static(), but with default values accommodated for fitlandr. See simlandr::make_3d_static() for details.
simlandr_options(
vf,
x = rlang::expr(vf$x),
y = rlang::expr(vf$y),
lims = rlang::expr(vf$lims),
kde_fun = c("ks", "MASS"),
n = 200,
adjust = 1,
h,
Umax = 5
)
vf |
A |
x, y |
The names of the target variables. |
lims |
The limits of the range for the density estimator as |
kde_fun |
Which kernel estimator to use? Choices: "ks" |
n |
The number of equally spaced points in each axis, at which the density is to be estimated. |
adjust |
The multiplier to the bandwidth. The bandwidth used is actually |
h |
A number, or possibly a vector for 3D and 4D landscapes, specifying the smoothing bandwidth to be used. If missing, the default value of the kernel estimator will be used (but |
Umax |
The maximum displayed value of potential. |
A list containing the parameters of the corresponding function. Only intended to be used within fit_3d_vfld()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.