Learn R Programming

fitlandr (version 0.1.1)

add_interp_grid: Add a grid to a vectorfield object to enable linear interpolation

Description

Add a grid to a vectorfield object to enable linear interpolation

Usage

add_interp_grid(vf, lims = vf$lims, n = vf$n)

Value

A vectorfield project with an interp_grid field.

Arguments

vf

A vectorfield object estimated by fit_2d_vf().

lims

The limits of the range for the vector field estimation as c(<xl>, <xu>, <yl>, <yu>). If missing, the range of the data extended by 10% for both sides will be used.

n

The number of equally spaced points in each axis, at which the vectors are to be estimated.