vectorfield object to enable linear interpolationAdd a grid to a vectorfield object to enable linear interpolation
add_interp_grid(vf, lims = vf$lims, n = vf$n)A vectorfield project with an interp_grid field.
A vectorfield object estimated by fit_2d_vf().
The limits of the range for the vector field estimation as c(<xl>, <xu>, <yl>, <yu>). If missing, the range of the data extended by 10% for both sides will be used.
The number of equally spaced points in each axis, at which the vectors are to be estimated.